# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/common/matcher/v3/matcher.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/common/matcher/v3/matcher.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.config.route.v3 import route_components_pb2 as envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2
from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,envoy/config/common/matcher/v3/matcher.proto\x12\x1e\x65nvoy.config.common.matcher.v3\x1a$envoy/config/core/v3/extension.proto\x1a,envoy/config/route/v3/route_components.proto\x1a\"envoy/type/matcher/v3/string.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xe3\x0f\n\x07Matcher\x12K\n\x0cmatcher_list\x18\x01 \x01(\x0b\x32\x33.envoy.config.common.matcher.v3.Matcher.MatcherListH\x00\x12K\n\x0cmatcher_tree\x18\x02 \x01(\x0b\x32\x33.envoy.config.common.matcher.v3.Matcher.MatcherTreeH\x00\x12\x44\n\x0bon_no_match\x18\x03 \x01(\x0b\x32/.envoy.config.common.matcher.v3.Matcher.OnMatch\x1a\x94\x01\n\x07OnMatch\x12:\n\x07matcher\x18\x01 \x01(\x0b\x32\'.envoy.config.common.matcher.v3.MatcherH\x00\x12<\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigH\x00\x42\x0f\n\x08on_match\x12\x03\xf8\x42\x01\x1a\xa5\x08\n\x0bMatcherList\x12\\\n\x08matchers\x18\x01 \x03(\x0b\x32@.envoy.config.common.matcher.v3.Matcher.MatcherList.FieldMatcherB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\xfd\x05\n\tPredicate\x12i\n\x10single_predicate\x18\x01 \x01(\x0b\x32M.envoy.config.common.matcher.v3.Matcher.MatcherList.Predicate.SinglePredicateH\x00\x12\x61\n\nor_matcher\x18\x02 \x01(\x0b\x32K.envoy.config.common.matcher.v3.Matcher.MatcherList.Predicate.PredicateListH\x00\x12\x62\n\x0b\x61nd_matcher\x18\x03 \x01(\x0b\x32K.envoy.config.common.matcher.v3.Matcher.MatcherList.Predicate.PredicateListH\x00\x12T\n\x0bnot_matcher\x18\x04 \x01(\x0b\x32=.envoy.config.common.matcher.v3.Matcher.MatcherList.PredicateH\x00\x1a\xe7\x01\n\x0fSinglePredicate\x12\x43\n\x05input\x18\x01 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12;\n\x0bvalue_match\x18\x02 \x01(\x0b\x32$.envoy.type.matcher.v3.StringMatcherH\x00\x12\x42\n\x0c\x63ustom_match\x18\x03 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigH\x00\x42\x0e\n\x07matcher\x12\x03\xf8\x42\x01\x1ak\n\rPredicateList\x12Z\n\tpredicate\x18\x01 \x03(\x0b\x32=.envoy.config.common.matcher.v3.Matcher.MatcherList.PredicateB\x08\xfa\x42\x05\x92\x01\x02\x08\x02\x42\x11\n\nmatch_type\x12\x03\xf8\x42\x01\x1a\xb7\x01\n\x0c\x46ieldMatcher\x12Z\n\tpredicate\x18\x01 \x01(\x0b\x32=.envoy.config.common.matcher.v3.Matcher.MatcherList.PredicateB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12K\n\x08on_match\x18\x02 \x01(\x0b\x32/.envoy.config.common.matcher.v3.Matcher.OnMatchB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x1a\xa3\x04\n\x0bMatcherTree\x12\x43\n\x05input\x18\x01 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12W\n\x0f\x65xact_match_map\x18\x02 \x01(\x0b\x32<.envoy.config.common.matcher.v3.Matcher.MatcherTree.MatchMapH\x00\x12X\n\x10prefix_match_map\x18\x03 \x01(\x0b\x32<.envoy.config.common.matcher.v3.Matcher.MatcherTree.MatchMapH\x00\x12\x42\n\x0c\x63ustom_match\x18\x04 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigH\x00\x1a\xc5\x01\n\x08MatchMap\x12\\\n\x03map\x18\x01 \x03(\x0b\x32\x45.envoy.config.common.matcher.v3.Matcher.MatcherTree.MatchMap.MapEntryB\x08\xfa\x42\x05\x9a\x01\x02\x08\x01\x1a[\n\x08MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12>\n\x05value\x18\x02 \x01(\x0b\x32/.envoy.config.common.matcher.v3.Matcher.OnMatch:\x02\x38\x01\x42\x10\n\ttree_type\x12\x03\xf8\x42\x01\x42\x13\n\x0cmatcher_type\x12\x03\xf8\x42\x01\"\x97\x07\n\x0eMatchPredicate\x12K\n\x08or_match\x18\x01 \x01(\x0b\x32\x37.envoy.config.common.matcher.v3.MatchPredicate.MatchSetH\x00\x12L\n\tand_match\x18\x02 \x01(\x0b\x32\x37.envoy.config.common.matcher.v3.MatchPredicate.MatchSetH\x00\x12\x43\n\tnot_match\x18\x03 \x01(\x0b\x32..envoy.config.common.matcher.v3.MatchPredicateH\x00\x12\x1c\n\tany_match\x18\x04 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12V\n\x1ahttp_request_headers_match\x18\x05 \x01(\x0b\x32\x30.envoy.config.common.matcher.v3.HttpHeadersMatchH\x00\x12W\n\x1bhttp_request_trailers_match\x18\x06 \x01(\x0b\x32\x30.envoy.config.common.matcher.v3.HttpHeadersMatchH\x00\x12W\n\x1bhttp_response_headers_match\x18\x07 \x01(\x0b\x32\x30.envoy.config.common.matcher.v3.HttpHeadersMatchH\x00\x12X\n\x1chttp_response_trailers_match\x18\x08 \x01(\x0b\x32\x30.envoy.config.common.matcher.v3.HttpHeadersMatchH\x00\x12_\n\x1fhttp_request_generic_body_match\x18\t \x01(\x0b\x32\x34.envoy.config.common.matcher.v3.HttpGenericBodyMatchH\x00\x12`\n http_response_generic_body_match\x18\n \x01(\x0b\x32\x34.envoy.config.common.matcher.v3.HttpGenericBodyMatchH\x00\x1aS\n\x08MatchSet\x12G\n\x05rules\x18\x01 \x03(\x0b\x32..envoy.config.common.matcher.v3.MatchPredicateB\x08\xfa\x42\x05\x92\x01\x02\x08\x02\x42\x0b\n\x04rule\x12\x03\xf8\x42\x01\"I\n\x10HttpHeadersMatch\x12\x35\n\x07headers\x18\x01 \x03(\x0b\x32$.envoy.config.route.v3.HeaderMatcher\"\xf1\x01\n\x14HttpGenericBodyMatch\x12\x13\n\x0b\x62ytes_limit\x18\x01 \x01(\r\x12\x61\n\x08patterns\x18\x02 \x03(\x0b\x32\x45.envoy.config.common.matcher.v3.HttpGenericBodyMatch.GenericTextMatchB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\x61\n\x10GenericTextMatch\x12\x1f\n\x0cstring_match\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x1f\n\x0c\x62inary_match\x18\x02 \x01(\x0c\x42\x07\xfa\x42\x04z\x02\x10\x01H\x00\x42\x0b\n\x04rule\x12\x03\xf8\x42\x01\x42\x97\x01\n,io.envoyproxy.envoy.config.common.matcher.v3B\x0cMatcherProtoP\x01ZOgithub.com/envoyproxy/go-control-plane/envoy/config/common/matcher/v3;matcherv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.common.matcher.v3.matcher_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n,io.envoyproxy.envoy.config.common.matcher.v3B\014MatcherProtoP\001ZOgithub.com/envoyproxy/go-control-plane/envoy/config/common/matcher/v3;matcherv3\272\200\310\321\006\002\020\002'
  _globals['_MATCHER_ONMATCH'].oneofs_by_name['on_match']._loaded_options = None
  _globals['_MATCHER_ONMATCH'].oneofs_by_name['on_match']._serialized_options = b'\370B\001'
  _globals['_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE'].oneofs_by_name['matcher']._loaded_options = None
  _globals['_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE'].oneofs_by_name['matcher']._serialized_options = b'\370B\001'
  _globals['_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE'].fields_by_name['input']._loaded_options = None
  _globals['_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE'].fields_by_name['input']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_MATCHER_MATCHERLIST_PREDICATE_PREDICATELIST'].fields_by_name['predicate']._loaded_options = None
  _globals['_MATCHER_MATCHERLIST_PREDICATE_PREDICATELIST'].fields_by_name['predicate']._serialized_options = b'\372B\005\222\001\002\010\002'
  _globals['_MATCHER_MATCHERLIST_PREDICATE'].oneofs_by_name['match_type']._loaded_options = None
  _globals['_MATCHER_MATCHERLIST_PREDICATE'].oneofs_by_name['match_type']._serialized_options = b'\370B\001'
  _globals['_MATCHER_MATCHERLIST_FIELDMATCHER'].fields_by_name['predicate']._loaded_options = None
  _globals['_MATCHER_MATCHERLIST_FIELDMATCHER'].fields_by_name['predicate']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_MATCHER_MATCHERLIST_FIELDMATCHER'].fields_by_name['on_match']._loaded_options = None
  _globals['_MATCHER_MATCHERLIST_FIELDMATCHER'].fields_by_name['on_match']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_MATCHER_MATCHERLIST'].fields_by_name['matchers']._loaded_options = None
  _globals['_MATCHER_MATCHERLIST'].fields_by_name['matchers']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_MATCHER_MATCHERTREE_MATCHMAP_MAPENTRY']._loaded_options = None
  _globals['_MATCHER_MATCHERTREE_MATCHMAP_MAPENTRY']._serialized_options = b'8\001'
  _globals['_MATCHER_MATCHERTREE_MATCHMAP'].fields_by_name['map']._loaded_options = None
  _globals['_MATCHER_MATCHERTREE_MATCHMAP'].fields_by_name['map']._serialized_options = b'\372B\005\232\001\002\010\001'
  _globals['_MATCHER_MATCHERTREE'].oneofs_by_name['tree_type']._loaded_options = None
  _globals['_MATCHER_MATCHERTREE'].oneofs_by_name['tree_type']._serialized_options = b'\370B\001'
  _globals['_MATCHER_MATCHERTREE'].fields_by_name['input']._loaded_options = None
  _globals['_MATCHER_MATCHERTREE'].fields_by_name['input']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_MATCHER'].oneofs_by_name['matcher_type']._loaded_options = None
  _globals['_MATCHER'].oneofs_by_name['matcher_type']._serialized_options = b'\370B\001'
  _globals['_MATCHPREDICATE_MATCHSET'].fields_by_name['rules']._loaded_options = None
  _globals['_MATCHPREDICATE_MATCHSET'].fields_by_name['rules']._serialized_options = b'\372B\005\222\001\002\010\002'
  _globals['_MATCHPREDICATE'].oneofs_by_name['rule']._loaded_options = None
  _globals['_MATCHPREDICATE'].oneofs_by_name['rule']._serialized_options = b'\370B\001'
  _globals['_MATCHPREDICATE'].fields_by_name['any_match']._loaded_options = None
  _globals['_MATCHPREDICATE'].fields_by_name['any_match']._serialized_options = b'\372B\004j\002\010\001'
  _globals['_HTTPGENERICBODYMATCH_GENERICTEXTMATCH'].oneofs_by_name['rule']._loaded_options = None
  _globals['_HTTPGENERICBODYMATCH_GENERICTEXTMATCH'].oneofs_by_name['rule']._serialized_options = b'\370B\001'
  _globals['_HTTPGENERICBODYMATCH_GENERICTEXTMATCH'].fields_by_name['string_match']._loaded_options = None
  _globals['_HTTPGENERICBODYMATCH_GENERICTEXTMATCH'].fields_by_name['string_match']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_HTTPGENERICBODYMATCH_GENERICTEXTMATCH'].fields_by_name['binary_match']._loaded_options = None
  _globals['_HTTPGENERICBODYMATCH_GENERICTEXTMATCH'].fields_by_name['binary_match']._serialized_options = b'\372B\004z\002\020\001'
  _globals['_HTTPGENERICBODYMATCH'].fields_by_name['patterns']._loaded_options = None
  _globals['_HTTPGENERICBODYMATCH'].fields_by_name['patterns']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_MATCHER']._serialized_start=257
  _globals['_MATCHER']._serialized_end=2276
  _globals['_MATCHER_ONMATCH']._serialized_start=493
  _globals['_MATCHER_ONMATCH']._serialized_end=641
  _globals['_MATCHER_MATCHERLIST']._serialized_start=644
  _globals['_MATCHER_MATCHERLIST']._serialized_end=1705
  _globals['_MATCHER_MATCHERLIST_PREDICATE']._serialized_start=754
  _globals['_MATCHER_MATCHERLIST_PREDICATE']._serialized_end=1519
  _globals['_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE']._serialized_start=1160
  _globals['_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE']._serialized_end=1391
  _globals['_MATCHER_MATCHERLIST_PREDICATE_PREDICATELIST']._serialized_start=1393
  _globals['_MATCHER_MATCHERLIST_PREDICATE_PREDICATELIST']._serialized_end=1500
  _globals['_MATCHER_MATCHERLIST_FIELDMATCHER']._serialized_start=1522
  _globals['_MATCHER_MATCHERLIST_FIELDMATCHER']._serialized_end=1705
  _globals['_MATCHER_MATCHERTREE']._serialized_start=1708
  _globals['_MATCHER_MATCHERTREE']._serialized_end=2255
  _globals['_MATCHER_MATCHERTREE_MATCHMAP']._serialized_start=2040
  _globals['_MATCHER_MATCHERTREE_MATCHMAP']._serialized_end=2237
  _globals['_MATCHER_MATCHERTREE_MATCHMAP_MAPENTRY']._serialized_start=2146
  _globals['_MATCHER_MATCHERTREE_MATCHMAP_MAPENTRY']._serialized_end=2237
  _globals['_MATCHPREDICATE']._serialized_start=2279
  _globals['_MATCHPREDICATE']._serialized_end=3198
  _globals['_MATCHPREDICATE_MATCHSET']._serialized_start=3102
  _globals['_MATCHPREDICATE_MATCHSET']._serialized_end=3185
  _globals['_HTTPHEADERSMATCH']._serialized_start=3200
  _globals['_HTTPHEADERSMATCH']._serialized_end=3273
  _globals['_HTTPGENERICBODYMATCH']._serialized_start=3276
  _globals['_HTTPGENERICBODYMATCH']._serialized_end=3517
  _globals['_HTTPGENERICBODYMATCH_GENERICTEXTMATCH']._serialized_start=3420
  _globals['_HTTPGENERICBODYMATCH_GENERICTEXTMATCH']._serialized_end=3517
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/quic/connection_debug_visitor/v3/connection_debug_visitor_basic.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/quic/connection_debug_visitor/v3/connection_debug_visitor_basic.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nVenvoy/extensions/quic/connection_debug_visitor/v3/connection_debug_visitor_basic.proto\x12\x31\x65nvoy.extensions.quic.connection_debug_visitor.v3\x1a\x1dudpa/annotations/status.proto\"\r\n\x0b\x42\x61sicConfigB\xe2\x01\n?io.envoyproxy.envoy.extensions.quic.connection_debug_visitor.v3B ConnectionDebugVisitorBasicProtoP\x01Zsgithub.com/envoyproxy/go-control-plane/envoy/extensions/quic/connection_debug_visitor/v3;connection_debug_visitorv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.quic.connection_debug_visitor.v3.connection_debug_visitor_basic_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n?io.envoyproxy.envoy.extensions.quic.connection_debug_visitor.v3B ConnectionDebugVisitorBasicProtoP\001Zsgithub.com/envoyproxy/go-control-plane/envoy/extensions/quic/connection_debug_visitor/v3;connection_debug_visitorv3\272\200\310\321\006\002\020\002'
  _globals['_BASICCONFIG']._serialized_start=172
  _globals['_BASICCONFIG']._serialized_end=185
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/trace/v3/skywalking.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/trace/v3/skywalking.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&envoy/config/trace/v3/skywalking.proto\x12\x15\x65nvoy.config.trace.v3\x1a\'envoy/config/core/v3/grpc_service.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x91\x01\n\x10SkyWalkingConfig\x12\x41\n\x0cgrpc_service\x18\x01 \x01(\x0b\x32!.envoy.config.core.v3.GrpcServiceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12:\n\rclient_config\x18\x02 \x01(\x0b\x32#.envoy.config.trace.v3.ClientConfig\"\xad\x01\n\x0c\x43lientConfig\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x15\n\rinstance_name\x18\x02 \x01(\t\x12\x1f\n\rbackend_token\x18\x03 \x01(\tB\x06\xb8\xb7\x8b\xa4\x02\x01H\x00\x12\x34\n\x0emax_cache_size\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x19\n\x17\x62\x61\x63kend_token_specifierB\xb9\x01\n#io.envoyproxy.envoy.config.trace.v3B\x0fSkywalkingProtoP\x01ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v3;tracev3\xf2\x98\xfe\x8f\x05-\x12+envoy.extensions.tracers.skywalking.v4alpha\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.trace.v3.skywalking_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#io.envoyproxy.envoy.config.trace.v3B\017SkywalkingProtoP\001ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v3;tracev3\362\230\376\217\005-\022+envoy.extensions.tracers.skywalking.v4alpha\272\200\310\321\006\002\020\002'
  _globals['_SKYWALKINGCONFIG'].fields_by_name['grpc_service']._loaded_options = None
  _globals['_SKYWALKINGCONFIG'].fields_by_name['grpc_service']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_CLIENTCONFIG'].fields_by_name['backend_token']._loaded_options = None
  _globals['_CLIENTCONFIG'].fields_by_name['backend_token']._serialized_options = b'\270\267\213\244\002\001'
  _globals['_SKYWALKINGCONFIG']._serialized_start=261
  _globals['_SKYWALKINGCONFIG']._serialized_end=406
  _globals['_CLIENTCONFIG']._serialized_start=409
  _globals['_CLIENTCONFIG']._serialized_end=582
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/matching/input_matchers/metadata/v3/metadata.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/matching/input_matchers/metadata/v3/metadata.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher.v3 import value_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_value__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCenvoy/extensions/matching/input_matchers/metadata/v3/metadata.proto\x12\x34\x65nvoy.extensions.matching.input_matchers.metadata.v3\x1a!envoy/type/matcher/v3/value.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"X\n\x08Metadata\x12<\n\x05value\x18\x01 \x01(\x0b\x32#.envoy.type.matcher.v3.ValueMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x0e\n\x06invert\x18\x04 \x01(\x08\x42\xc5\x01\nBio.envoyproxy.envoy.extensions.matching.input_matchers.metadata.v3B\rMetadataProtoP\x01Zfgithub.com/envoyproxy/go-control-plane/envoy/extensions/matching/input_matchers/metadata/v3;metadatav3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.matching.input_matchers.metadata.v3.metadata_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\nBio.envoyproxy.envoy.extensions.matching.input_matchers.metadata.v3B\rMetadataProtoP\001Zfgithub.com/envoyproxy/go-control-plane/envoy/extensions/matching/input_matchers/metadata/v3;metadatav3\272\200\310\321\006\002\020\002'
  _globals['_METADATA'].fields_by_name['value']._loaded_options = None
  _globals['_METADATA'].fields_by_name['value']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_METADATA']._serialized_start=216
  _globals['_METADATA']._serialized_end=304
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/core/v3/address.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/core/v3/address.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.config.core.v3 import socket_option_pb2 as envoy_dot_config_dot_core_dot_v3_dot_socket__option__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"envoy/config/core/v3/address.proto\x12\x14\x65nvoy.config.core.v3\x1a$envoy/config/core/v3/extension.proto\x1a(envoy/config/core/v3/socket_option.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"T\n\x04Pipe\x12\x15\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x16\n\x04mode\x18\x02 \x01(\rB\x08\xfa\x42\x05*\x03\x18\xff\x03:\x1d\x9a\xc5\x88\x1e\x18\n\x16\x65nvoy.api.v2.core.Pipe\"j\n\x14\x45nvoyInternalAddress\x12\x1e\n\x14server_listener_name\x18\x01 \x01(\tH\x00\x12\x13\n\x0b\x65ndpoint_id\x18\x02 \x01(\tB\x1d\n\x16\x61\x64\x64ress_name_specifier\x12\x03\xf8\x42\x01\"\xb3\x02\n\rSocketAddress\x12H\n\x08protocol\x18\x01 \x01(\x0e\x32,.envoy.config.core.v3.SocketAddress.ProtocolB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1f\n\nport_value\x18\x03 \x01(\rB\t\xfa\x42\x06*\x04\x18\xff\xff\x03H\x00\x12\x14\n\nnamed_port\x18\x04 \x01(\tH\x00\x12\x15\n\rresolver_name\x18\x05 \x01(\t\x12\x13\n\x0bipv4_compat\x18\x06 \x01(\x08\"\x1c\n\x08Protocol\x12\x07\n\x03TCP\x10\x00\x12\x07\n\x03UDP\x10\x01:&\x9a\xc5\x88\x1e!\n\x1f\x65nvoy.api.v2.core.SocketAddressB\x15\n\x0eport_specifier\x12\x03\xf8\x42\x01\"\xdd\x01\n\x0cTcpKeepalive\x12\x36\n\x10keepalive_probes\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x34\n\x0ekeepalive_time\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x38\n\x12keepalive_interval\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value:%\x9a\xc5\x88\x1e \n\x1e\x65nvoy.api.v2.core.TcpKeepalive\"\x99\x01\n\x12\x45xtraSourceAddress\x12>\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32#.envoy.config.core.v3.SocketAddressB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x43\n\x0esocket_options\x18\x02 \x01(\x0b\x32+.envoy.config.core.v3.SocketOptionsOverride\"\xc5\x03\n\nBindConfig\x12;\n\x0esource_address\x18\x01 \x01(\x0b\x32#.envoy.config.core.v3.SocketAddress\x12,\n\x08\x66reebind\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12:\n\x0esocket_options\x18\x03 \x03(\x0b\x32\".envoy.config.core.v3.SocketOption\x12H\n\x16\x65xtra_source_addresses\x18\x05 \x03(\x0b\x32(.envoy.config.core.v3.ExtraSourceAddress\x12U\n\x1b\x61\x64\x64itional_source_addresses\x18\x04 \x03(\x0b\x32#.envoy.config.core.v3.SocketAddressB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12J\n\x16local_address_selector\x18\x06 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig:#\x9a\xc5\x88\x1e\x1e\n\x1c\x65nvoy.api.v2.core.BindConfig\"\xf4\x01\n\x07\x41\x64\x64ress\x12=\n\x0esocket_address\x18\x01 \x01(\x0b\x32#.envoy.config.core.v3.SocketAddressH\x00\x12*\n\x04pipe\x18\x02 \x01(\x0b\x32\x1a.envoy.config.core.v3.PipeH\x00\x12L\n\x16\x65nvoy_internal_address\x18\x03 \x01(\x0b\x32*.envoy.config.core.v3.EnvoyInternalAddressH\x00: \x9a\xc5\x88\x1e\x1b\n\x19\x65nvoy.api.v2.core.AddressB\x0e\n\x07\x61\x64\x64ress\x12\x03\xf8\x42\x01\"\x8c\x01\n\tCidrRange\x12\x1f\n\x0e\x61\x64\x64ress_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12:\n\nprefix_len\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x08\xfa\x42\x05*\x03\x18\x80\x01:\"\x9a\xc5\x88\x1e\x1d\n\x1b\x65nvoy.api.v2.core.CidrRangeB\x80\x01\n\"io.envoyproxy.envoy.config.core.v3B\x0c\x41\x64\x64ressProtoP\x01ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.core.v3.address_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"io.envoyproxy.envoy.config.core.v3B\014AddressProtoP\001ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\272\200\310\321\006\002\020\002'
  _globals['_PIPE'].fields_by_name['path']._loaded_options = None
  _globals['_PIPE'].fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_PIPE'].fields_by_name['mode']._loaded_options = None
  _globals['_PIPE'].fields_by_name['mode']._serialized_options = b'\372B\005*\003\030\377\003'
  _globals['_PIPE']._loaded_options = None
  _globals['_PIPE']._serialized_options = b'\232\305\210\036\030\n\026envoy.api.v2.core.Pipe'
  _globals['_ENVOYINTERNALADDRESS'].oneofs_by_name['address_name_specifier']._loaded_options = None
  _globals['_ENVOYINTERNALADDRESS'].oneofs_by_name['address_name_specifier']._serialized_options = b'\370B\001'
  _globals['_SOCKETADDRESS'].oneofs_by_name['port_specifier']._loaded_options = None
  _globals['_SOCKETADDRESS'].oneofs_by_name['port_specifier']._serialized_options = b'\370B\001'
  _globals['_SOCKETADDRESS'].fields_by_name['protocol']._loaded_options = None
  _globals['_SOCKETADDRESS'].fields_by_name['protocol']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_SOCKETADDRESS'].fields_by_name['address']._loaded_options = None
  _globals['_SOCKETADDRESS'].fields_by_name['address']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_SOCKETADDRESS'].fields_by_name['port_value']._loaded_options = None
  _globals['_SOCKETADDRESS'].fields_by_name['port_value']._serialized_options = b'\372B\006*\004\030\377\377\003'
  _globals['_SOCKETADDRESS']._loaded_options = None
  _globals['_SOCKETADDRESS']._serialized_options = b'\232\305\210\036!\n\037envoy.api.v2.core.SocketAddress'
  _globals['_TCPKEEPALIVE']._loaded_options = None
  _globals['_TCPKEEPALIVE']._serialized_options = b'\232\305\210\036 \n\036envoy.api.v2.core.TcpKeepalive'
  _globals['_EXTRASOURCEADDRESS'].fields_by_name['address']._loaded_options = None
  _globals['_EXTRASOURCEADDRESS'].fields_by_name['address']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_BINDCONFIG'].fields_by_name['additional_source_addresses']._loaded_options = None
  _globals['_BINDCONFIG'].fields_by_name['additional_source_addresses']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _globals['_BINDCONFIG']._loaded_options = None
  _globals['_BINDCONFIG']._serialized_options = b'\232\305\210\036\036\n\034envoy.api.v2.core.BindConfig'
  _globals['_ADDRESS'].oneofs_by_name['address']._loaded_options = None
  _globals['_ADDRESS'].oneofs_by_name['address']._serialized_options = b'\370B\001'
  _globals['_ADDRESS']._loaded_options = None
  _globals['_ADDRESS']._serialized_options = b'\232\305\210\036\033\n\031envoy.api.v2.core.Address'
  _globals['_CIDRRANGE'].fields_by_name['address_prefix']._loaded_options = None
  _globals['_CIDRRANGE'].fields_by_name['address_prefix']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CIDRRANGE'].fields_by_name['prefix_len']._loaded_options = None
  _globals['_CIDRRANGE'].fields_by_name['prefix_len']._serialized_options = b'\372B\005*\003\030\200\001'
  _globals['_CIDRRANGE']._loaded_options = None
  _globals['_CIDRRANGE']._serialized_options = b'\232\305\210\036\035\n\033envoy.api.v2.core.CidrRange'
  _globals['_PIPE']._serialized_start=300
  _globals['_PIPE']._serialized_end=384
  _globals['_ENVOYINTERNALADDRESS']._serialized_start=386
  _globals['_ENVOYINTERNALADDRESS']._serialized_end=492
  _globals['_SOCKETADDRESS']._serialized_start=495
  _globals['_SOCKETADDRESS']._serialized_end=802
  _globals['_SOCKETADDRESS_PROTOCOL']._serialized_start=711
  _globals['_SOCKETADDRESS_PROTOCOL']._serialized_end=739
  _globals['_TCPKEEPALIVE']._serialized_start=805
  _globals['_TCPKEEPALIVE']._serialized_end=1026
  _globals['_EXTRASOURCEADDRESS']._serialized_start=1029
  _globals['_EXTRASOURCEADDRESS']._serialized_end=1182
  _globals['_BINDCONFIG']._serialized_start=1185
  _globals['_BINDCONFIG']._serialized_end=1638
  _globals['_ADDRESS']._serialized_start=1641
  _globals['_ADDRESS']._serialized_end=1885
  _globals['_CIDRRANGE']._serialized_start=1888
  _globals['_CIDRRANGE']._serialized_end=2028
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/access_loggers/wasm/v3/wasm.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/access_loggers/wasm/v3/wasm.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.wasm.v3 import wasm_pb2 as envoy_dot_extensions_dot_wasm_dot_v3_dot_wasm__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2envoy/extensions/access_loggers/wasm/v3/wasm.proto\x12\'envoy.extensions.access_loggers.wasm.v3\x1a#envoy/extensions/wasm/v3/wasm.proto\x1a\x1dudpa/annotations/status.proto\"G\n\rWasmAccessLog\x12\x36\n\x06\x63onfig\x18\x01 \x01(\x0b\x32&.envoy.extensions.wasm.v3.PluginConfigB\xa3\x01\n5io.envoyproxy.envoy.extensions.access_loggers.wasm.v3B\tWasmProtoP\x01ZUgithub.com/envoyproxy/go-control-plane/envoy/extensions/access_loggers/wasm/v3;wasmv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.access_loggers.wasm.v3.wasm_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n5io.envoyproxy.envoy.extensions.access_loggers.wasm.v3B\tWasmProtoP\001ZUgithub.com/envoyproxy/go-control-plane/envoy/extensions/access_loggers/wasm/v3;wasmv3\272\200\310\321\006\002\020\002'
  _globals['_WASMACCESSLOG']._serialized_start=163
  _globals['_WASMACCESSLOG']._serialized_end=234
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/api/servicecontrol/v1/log_entry.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'google/api/servicecontrol/v1/log_entry.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api.servicecontrol.v1 import http_request_pb2 as google_dot_api_dot_servicecontrol_dot_v1_dot_http__request__pb2
from google.logging.type import log_severity_pb2 as google_dot_logging_dot_type_dot_log__severity__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,google/api/servicecontrol/v1/log_entry.proto\x12\x1cgoogle.api.servicecontrol.v1\x1a/google/api/servicecontrol/v1/http_request.proto\x1a&google/logging/type/log_severity.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe9\x04\n\x08LogEntry\x12\x0c\n\x04name\x18\n \x01(\t\x12-\n\ttimestamp\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x08severity\x18\x0c \x01(\x0e\x32 .google.logging.type.LogSeverity\x12?\n\x0chttp_request\x18\x0e \x01(\x0b\x32).google.api.servicecontrol.v1.HttpRequest\x12\r\n\x05trace\x18\x0f \x01(\t\x12\x11\n\tinsert_id\x18\x04 \x01(\t\x12\x42\n\x06labels\x18\r \x03(\x0b\x32\x32.google.api.servicecontrol.v1.LogEntry.LabelsEntry\x12-\n\rproto_payload\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12\x16\n\x0ctext_payload\x18\x03 \x01(\tH\x00\x12\x31\n\x0estruct_payload\x18\x06 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x12\x42\n\toperation\x18\x10 \x01(\x0b\x32/.google.api.servicecontrol.v1.LogEntryOperation\x12M\n\x0fsource_location\x18\x11 \x01(\x0b\x32\x34.google.api.servicecontrol.v1.LogEntrySourceLocation\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\t\n\x07payload\"N\n\x11LogEntryOperation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08producer\x18\x02 \x01(\t\x12\r\n\x05\x66irst\x18\x03 \x01(\x08\x12\x0c\n\x04last\x18\x04 \x01(\x08\"F\n\x16LogEntrySourceLocation\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t\x12\x0c\n\x04line\x18\x02 \x01(\x03\x12\x10\n\x08\x66unction\x18\x03 \x01(\tB\xe5\x01\n com.google.api.servicecontrol.v1B\rLogEntryProtoP\x01ZJcloud.google.com/go/servicecontrol/apiv1/servicecontrolpb;servicecontrolpb\xaa\x02\x1eGoogle.Cloud.ServiceControl.V1\xca\x02\x1eGoogle\\Cloud\\ServiceControl\\V1\xea\x02!Google::Cloud::ServiceControl::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.servicecontrol.v1.log_entry_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.google.api.servicecontrol.v1B\rLogEntryProtoP\001ZJcloud.google.com/go/servicecontrol/apiv1/servicecontrolpb;servicecontrolpb\252\002\036Google.Cloud.ServiceControl.V1\312\002\036Google\\Cloud\\ServiceControl\\V1\352\002!Google::Cloud::ServiceControl::V1'
  _globals['_LOGENTRY_LABELSENTRY']._loaded_options = None
  _globals['_LOGENTRY_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_LOGENTRY']._serialized_start=258
  _globals['_LOGENTRY']._serialized_end=875
  _globals['_LOGENTRY_LABELSENTRY']._serialized_start=819
  _globals['_LOGENTRY_LABELSENTRY']._serialized_end=864
  _globals['_LOGENTRYOPERATION']._serialized_start=877
  _globals['_LOGENTRYOPERATION']._serialized_end=955
  _globals['_LOGENTRYSOURCELOCATION']._serialized_start=957
  _globals['_LOGENTRYSOURCELOCATION']._serialized_end=1027
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/admin/v3/clusters.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/admin/v3/clusters.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.admin.v3 import metrics_pb2 as envoy_dot_admin_dot_v3_dot_metrics__pb2
from envoy.config.cluster.v3 import circuit_breaker_pb2 as envoy_dot_config_dot_cluster_dot_v3_dot_circuit__breaker__pb2
from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import health_check_pb2 as envoy_dot_config_dot_core_dot_v3_dot_health__check__pb2
from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65nvoy/admin/v3/clusters.proto\x12\x0e\x65nvoy.admin.v3\x1a\x1c\x65nvoy/admin/v3/metrics.proto\x1a-envoy/config/cluster/v3/circuit_breaker.proto\x1a\"envoy/config/core/v3/address.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\'envoy/config/core/v3/health_check.proto\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"h\n\x08\x43lusters\x12\x37\n\x10\x63luster_statuses\x18\x01 \x03(\x0b\x32\x1d.envoy.admin.v3.ClusterStatus:#\x9a\xc5\x88\x1e\x1e\n\x1c\x65nvoy.admin.v2alpha.Clusters\"\x9a\x03\n\rClusterStatus\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\radded_via_api\x18\x02 \x01(\x08\x12?\n\x1fsuccess_rate_ejection_threshold\x18\x03 \x01(\x0b\x32\x16.envoy.type.v3.Percent\x12\x31\n\rhost_statuses\x18\x04 \x03(\x0b\x32\x1a.envoy.admin.v3.HostStatus\x12L\n,local_origin_success_rate_ejection_threshold\x18\x05 \x01(\x0b\x32\x16.envoy.type.v3.Percent\x12\x42\n\x10\x63ircuit_breakers\x18\x06 \x01(\x0b\x32(.envoy.config.cluster.v3.CircuitBreakers\x12\x1a\n\x12observability_name\x18\x07 \x01(\t\x12\x18\n\x10\x65\x64s_service_name\x18\x08 \x01(\t:(\x9a\xc5\x88\x1e#\n!envoy.admin.v2alpha.ClusterStatus\"\x98\x03\n\nHostStatus\x12.\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1d.envoy.config.core.v3.Address\x12+\n\x05stats\x18\x02 \x03(\x0b\x32\x1c.envoy.admin.v3.SimpleMetric\x12\x37\n\rhealth_status\x18\x03 \x01(\x0b\x32 .envoy.admin.v3.HostHealthStatus\x12,\n\x0csuccess_rate\x18\x04 \x01(\x0b\x32\x16.envoy.type.v3.Percent\x12\x0e\n\x06weight\x18\x05 \x01(\r\x12\x10\n\x08hostname\x18\x06 \x01(\t\x12\x10\n\x08priority\x18\x07 \x01(\r\x12\x39\n\x19local_origin_success_rate\x18\x08 \x01(\x0b\x32\x16.envoy.type.v3.Percent\x12\x30\n\x08locality\x18\t \x01(\x0b\x32\x1e.envoy.config.core.v3.Locality:%\x9a\xc5\x88\x1e \n\x1e\x65nvoy.admin.v2alpha.HostStatus\"\xe5\x02\n\x10HostHealthStatus\x12\"\n\x1a\x66\x61iled_active_health_check\x18\x01 \x01(\x08\x12\x1c\n\x14\x66\x61iled_outlier_check\x18\x02 \x01(\x08\x12$\n\x1c\x66\x61iled_active_degraded_check\x18\x04 \x01(\x08\x12\x1f\n\x17pending_dynamic_removal\x18\x05 \x01(\x08\x12\x19\n\x11pending_active_hc\x18\x06 \x01(\x08\x12&\n\x1e\x65xcluded_via_immediate_hc_fail\x18\x07 \x01(\x08\x12\x19\n\x11\x61\x63tive_hc_timeout\x18\x08 \x01(\x08\x12=\n\x11\x65\x64s_health_status\x18\x03 \x01(\x0e\x32\".envoy.config.core.v3.HealthStatus:+\x9a\xc5\x88\x1e&\n$envoy.admin.v2alpha.HostHealthStatusBv\n\x1cio.envoyproxy.envoy.admin.v3B\rClustersProtoP\x01Z=github.com/envoyproxy/go-control-plane/envoy/admin/v3;adminv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.admin.v3.clusters_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034io.envoyproxy.envoy.admin.v3B\rClustersProtoP\001Z=github.com/envoyproxy/go-control-plane/envoy/admin/v3;adminv3\272\200\310\321\006\002\020\002'
  _globals['_CLUSTERS']._loaded_options = None
  _globals['_CLUSTERS']._serialized_options = b'\232\305\210\036\036\n\034envoy.admin.v2alpha.Clusters'
  _globals['_CLUSTERSTATUS']._loaded_options = None
  _globals['_CLUSTERSTATUS']._serialized_options = b'\232\305\210\036#\n!envoy.admin.v2alpha.ClusterStatus'
  _globals['_HOSTSTATUS']._loaded_options = None
  _globals['_HOSTSTATUS']._serialized_options = b'\232\305\210\036 \n\036envoy.admin.v2alpha.HostStatus'
  _globals['_HOSTHEALTHSTATUS']._loaded_options = None
  _globals['_HOSTHEALTHSTATUS']._serialized_options = b'\232\305\210\036&\n$envoy.admin.v2alpha.HostHealthStatus'
  _globals['_CLUSTERS']._serialized_start=331
  _globals['_CLUSTERS']._serialized_end=435
  _globals['_CLUSTERSTATUS']._serialized_start=438
  _globals['_CLUSTERSTATUS']._serialized_end=848
  _globals['_HOSTSTATUS']._serialized_start=851
  _globals['_HOSTSTATUS']._serialized_end=1259
  _globals['_HOSTHEALTHSTATUS']._serialized_start=1262
  _globals['_HOSTHEALTHSTATUS']._serialized_end=1619
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/admin/v3/config_dump.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/admin/v3/config_dump.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.admin.v3 import config_dump_shared_pb2 as envoy_dot_admin_dot_v3_dot_config__dump__shared__pb2
from envoy.config.bootstrap.v3 import bootstrap_pb2 as envoy_dot_config_dot_bootstrap_dot_v3_dot_bootstrap__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n envoy/admin/v3/config_dump.proto\x12\x0e\x65nvoy.admin.v3\x1a\'envoy/admin/v3/config_dump_shared.proto\x1a)envoy/config/bootstrap/v3/bootstrap.proto\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"Z\n\nConfigDump\x12%\n\x07\x63onfigs\x18\x01 \x03(\x0b\x32\x14.google.protobuf.Any:%\x9a\xc5\x88\x1e \n\x1e\x65nvoy.admin.v2alpha.ConfigDump\"\xb0\x01\n\x13\x42ootstrapConfigDump\x12\x37\n\tbootstrap\x18\x01 \x01(\x0b\x32$.envoy.config.bootstrap.v3.Bootstrap\x12\x30\n\x0clast_updated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:.\x9a\xc5\x88\x1e)\n\'envoy.admin.v2alpha.BootstrapConfigDump\"\x9e\x06\n\x11SecretsConfigDump\x12\x46\n\x0estatic_secrets\x18\x01 \x03(\x0b\x32..envoy.admin.v3.SecretsConfigDump.StaticSecret\x12O\n\x16\x64ynamic_active_secrets\x18\x02 \x03(\x0b\x32/.envoy.admin.v3.SecretsConfigDump.DynamicSecret\x12P\n\x17\x64ynamic_warming_secrets\x18\x03 \x03(\x0b\x32/.envoy.admin.v3.SecretsConfigDump.DynamicSecret\x1a\xbd\x02\n\rDynamicSecret\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cversion_info\x18\x02 \x01(\t\x12\x30\n\x0clast_updated\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12$\n\x06secret\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x37\n\x0b\x65rror_state\x18\x05 \x01(\x0b\x32\".envoy.admin.v3.UpdateFailureState\x12;\n\rclient_status\x18\x06 \x01(\x0e\x32$.envoy.admin.v3.ClientResourceStatus::\x9a\xc5\x88\x1e\x35\n3envoy.admin.v2alpha.SecretsConfigDump.DynamicSecret\x1a\xaf\x01\n\x0cStaticSecret\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x30\n\x0clast_updated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12$\n\x06secret\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any:9\x9a\xc5\x88\x1e\x34\n2envoy.admin.v2alpha.SecretsConfigDump.StaticSecret:,\x9a\xc5\x88\x1e\'\n%envoy.admin.v2alpha.SecretsConfigDumpBx\n\x1cio.envoyproxy.envoy.admin.v3B\x0f\x43onfigDumpProtoP\x01Z=github.com/envoyproxy/go-control-plane/envoy/admin/v3;adminv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.admin.v3.config_dump_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034io.envoyproxy.envoy.admin.v3B\017ConfigDumpProtoP\001Z=github.com/envoyproxy/go-control-plane/envoy/admin/v3;adminv3\272\200\310\321\006\002\020\002'
  _globals['_CONFIGDUMP']._loaded_options = None
  _globals['_CONFIGDUMP']._serialized_options = b'\232\305\210\036 \n\036envoy.admin.v2alpha.ConfigDump'
  _globals['_BOOTSTRAPCONFIGDUMP']._loaded_options = None
  _globals['_BOOTSTRAPCONFIGDUMP']._serialized_options = b'\232\305\210\036)\n\'envoy.admin.v2alpha.BootstrapConfigDump'
  _globals['_SECRETSCONFIGDUMP_DYNAMICSECRET']._loaded_options = None
  _globals['_SECRETSCONFIGDUMP_DYNAMICSECRET']._serialized_options = b'\232\305\210\0365\n3envoy.admin.v2alpha.SecretsConfigDump.DynamicSecret'
  _globals['_SECRETSCONFIGDUMP_STATICSECRET']._loaded_options = None
  _globals['_SECRETSCONFIGDUMP_STATICSECRET']._serialized_options = b'\232\305\210\0364\n2envoy.admin.v2alpha.SecretsConfigDump.StaticSecret'
  _globals['_SECRETSCONFIGDUMP']._loaded_options = None
  _globals['_SECRETSCONFIGDUMP']._serialized_options = b'\232\305\210\036\'\n%envoy.admin.v2alpha.SecretsConfigDump'
  _globals['_CONFIGDUMP']._serialized_start=262
  _globals['_CONFIGDUMP']._serialized_end=352
  _globals['_BOOTSTRAPCONFIGDUMP']._serialized_start=355
  _globals['_BOOTSTRAPCONFIGDUMP']._serialized_end=531
  _globals['_SECRETSCONFIGDUMP']._serialized_start=534
  _globals['_SECRETSCONFIGDUMP']._serialized_end=1332
  _globals['_SECRETSCONFIGDUMP_DYNAMICSECRET']._serialized_start=791
  _globals['_SECRETSCONFIGDUMP_DYNAMICSECRET']._serialized_end=1108
  _globals['_SECRETSCONFIGDUMP_STATICSECRET']._serialized_start=1111
  _globals['_SECRETSCONFIGDUMP_STATICSECRET']._serialized_end=1286
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/expr/v1alpha1/conformance_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api.expr.v1alpha1 import checked_pb2 as google_dot_api_dot_expr_dot_v1alpha1_dot_checked__pb2
from google.api.expr.v1alpha1 import eval_pb2 as google_dot_api_dot_expr_dot_v1alpha1_dot_eval__pb2
from google.api.expr.v1alpha1 import syntax_pb2 as google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2google/api/expr/v1alpha1/conformance_service.proto\x12\x18google.api.expr.v1alpha1\x1a&google/api/expr/v1alpha1/checked.proto\x1a#google/api/expr/v1alpha1/eval.proto\x1a%google/api/expr/v1alpha1/syntax.proto\x1a\x17google/rpc/status.proto\"k\n\x0cParseRequest\x12\x12\n\ncel_source\x18\x01 \x01(\t\x12\x16\n\x0esyntax_version\x18\x02 \x01(\t\x12\x17\n\x0fsource_location\x18\x03 \x01(\t\x12\x16\n\x0e\x64isable_macros\x18\x04 \x01(\x08\"n\n\rParseResponse\x12\x39\n\x0bparsed_expr\x18\x01 \x01(\x0b\x32$.google.api.expr.v1alpha1.ParsedExpr\x12\"\n\x06issues\x18\x02 \x03(\x0b\x32\x12.google.rpc.Status\"\xa2\x01\n\x0c\x43heckRequest\x12\x39\n\x0bparsed_expr\x18\x01 \x01(\x0b\x32$.google.api.expr.v1alpha1.ParsedExpr\x12\x30\n\x08type_env\x18\x02 \x03(\x0b\x32\x1e.google.api.expr.v1alpha1.Decl\x12\x11\n\tcontainer\x18\x03 \x01(\t\x12\x12\n\nno_std_env\x18\x04 \x01(\x08\"p\n\rCheckResponse\x12;\n\x0c\x63hecked_expr\x18\x01 \x01(\x0b\x32%.google.api.expr.v1alpha1.CheckedExpr\x12\"\n\x06issues\x18\x02 \x03(\x0b\x32\x12.google.rpc.Status\"\xc6\x02\n\x0b\x45valRequest\x12;\n\x0bparsed_expr\x18\x01 \x01(\x0b\x32$.google.api.expr.v1alpha1.ParsedExprH\x00\x12=\n\x0c\x63hecked_expr\x18\x02 \x01(\x0b\x32%.google.api.expr.v1alpha1.CheckedExprH\x00\x12\x45\n\x08\x62indings\x18\x03 \x03(\x0b\x32\x33.google.api.expr.v1alpha1.EvalRequest.BindingsEntry\x12\x11\n\tcontainer\x18\x04 \x01(\t\x1aT\n\rBindingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.google.api.expr.v1alpha1.ExprValue:\x02\x38\x01\x42\x0b\n\texpr_kind\"g\n\x0c\x45valResponse\x12\x33\n\x06result\x18\x01 \x01(\x0b\x32#.google.api.expr.v1alpha1.ExprValue\x12\"\n\x06issues\x18\x02 \x03(\x0b\x32\x12.google.rpc.Status\"\xe8\x01\n\x0cIssueDetails\x12\x41\n\x08severity\x18\x01 \x01(\x0e\x32/.google.api.expr.v1alpha1.IssueDetails.Severity\x12:\n\x08position\x18\x02 \x01(\x0b\x32(.google.api.expr.v1alpha1.SourcePosition\x12\n\n\x02id\x18\x03 \x01(\x03\"M\n\x08Severity\x12\x18\n\x14SEVERITY_UNSPECIFIED\x10\x00\x12\x0f\n\x0b\x44\x45PRECATION\x10\x01\x12\x0b\n\x07WARNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x32\xa5\x02\n\x12\x43onformanceService\x12Z\n\x05Parse\x12&.google.api.expr.v1alpha1.ParseRequest\x1a\'.google.api.expr.v1alpha1.ParseResponse\"\x00\x12Z\n\x05\x43heck\x12&.google.api.expr.v1alpha1.CheckRequest\x1a\'.google.api.expr.v1alpha1.CheckResponse\"\x00\x12W\n\x04\x45val\x12%.google.api.expr.v1alpha1.EvalRequest\x1a&.google.api.expr.v1alpha1.EvalResponse\"\x00\x42\x88\x01\n\x1c\x63om.google.api.expr.v1alpha1B\x17\x43onformanceServiceProtoP\x01ZJgoogle.golang.org/genproto/googleapis/api/expr/conformance/v1alpha1;confpb\xf8\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.expr.v1alpha1.conformance_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.google.api.expr.v1alpha1B\027ConformanceServiceProtoP\001ZJgoogle.golang.org/genproto/googleapis/api/expr/conformance/v1alpha1;confpb\370\001\001'
  _EVALREQUEST_BINDINGSENTRY._options = None
  _EVALREQUEST_BINDINGSENTRY._serialized_options = b'8\001'
  _globals['_PARSEREQUEST']._serialized_start=221
  _globals['_PARSEREQUEST']._serialized_end=328
  _globals['_PARSERESPONSE']._serialized_start=330
  _globals['_PARSERESPONSE']._serialized_end=440
  _globals['_CHECKREQUEST']._serialized_start=443
  _globals['_CHECKREQUEST']._serialized_end=605
  _globals['_CHECKRESPONSE']._serialized_start=607
  _globals['_CHECKRESPONSE']._serialized_end=719
  _globals['_EVALREQUEST']._serialized_start=722
  _globals['_EVALREQUEST']._serialized_end=1048
  _globals['_EVALREQUEST_BINDINGSENTRY']._serialized_start=951
  _globals['_EVALREQUEST_BINDINGSENTRY']._serialized_end=1035
  _globals['_EVALRESPONSE']._serialized_start=1050
  _globals['_EVALRESPONSE']._serialized_end=1153
  _globals['_ISSUEDETAILS']._serialized_start=1156
  _globals['_ISSUEDETAILS']._serialized_end=1388
  _globals['_ISSUEDETAILS_SEVERITY']._serialized_start=1311
  _globals['_ISSUEDETAILS_SEVERITY']._serialized_end=1388
  _globals['_CONFORMANCESERVICE']._serialized_start=1391
  _globals['_CONFORMANCESERVICE']._serialized_end=1684
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/service/auth/v2/external_auth.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/service/auth/v2/external_auth.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.service.auth.v2 import attribute_context_pb2 as envoy_dot_service_dot_auth_dot_v2_dot_attribute__context__pb2
from envoy.type import http_status_pb2 as envoy_dot_type_dot_http__status__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)envoy/service/auth/v2/external_auth.proto\x12\x15\x65nvoy.service.auth.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a-envoy/service/auth/v2/attribute_context.proto\x1a\x1c\x65nvoy/type/http_status.proto\x1a\x17google/rpc/status.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"K\n\x0c\x43heckRequest\x12;\n\nattributes\x18\x01 \x01(\x0b\x32\'.envoy.service.auth.v2.AttributeContext\"\x8b\x01\n\x12\x44\x65niedHttpResponse\x12\x30\n\x06status\x18\x01 \x01(\x0b\x32\x16.envoy.type.HttpStatusB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x35\n\x07headers\x18\x02 \x03(\x0b\x32$.envoy.api.v2.core.HeaderValueOption\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\"G\n\x0eOkHttpResponse\x12\x35\n\x07headers\x18\x02 \x03(\x0b\x32$.envoy.api.v2.core.HeaderValueOption\"\xc8\x01\n\rCheckResponse\x12\"\n\x06status\x18\x01 \x01(\x0b\x32\x12.google.rpc.Status\x12\x44\n\x0f\x64\x65nied_response\x18\x02 \x01(\x0b\x32).envoy.service.auth.v2.DeniedHttpResponseH\x00\x12<\n\x0bok_response\x18\x03 \x01(\x0b\x32%.envoy.service.auth.v2.OkHttpResponseH\x00\x42\x0f\n\rhttp_response2e\n\rAuthorization\x12T\n\x05\x43heck\x12#.envoy.service.auth.v2.CheckRequest\x1a$.envoy.service.auth.v2.CheckResponse\"\x00\x42\x87\x01\n#io.envoyproxy.envoy.service.auth.v2B\x11\x45xternalAuthProtoP\x01ZCgithub.com/envoyproxy/go-control-plane/envoy/service/auth/v2;authv2\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.auth.v2.external_auth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#io.envoyproxy.envoy.service.auth.v2B\021ExternalAuthProtoP\001ZCgithub.com/envoyproxy/go-control-plane/envoy/service/auth/v2;authv2\272\200\310\321\006\002\020\001'
  _globals['_DENIEDHTTPRESPONSE'].fields_by_name['status']._loaded_options = None
  _globals['_DENIEDHTTPRESPONSE'].fields_by_name['status']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_CHECKREQUEST']._serialized_start=256
  _globals['_CHECKREQUEST']._serialized_end=331
  _globals['_DENIEDHTTPRESPONSE']._serialized_start=334
  _globals['_DENIEDHTTPRESPONSE']._serialized_end=473
  _globals['_OKHTTPRESPONSE']._serialized_start=475
  _globals['_OKHTTPRESPONSE']._serialized_end=546
  _globals['_CHECKRESPONSE']._serialized_start=549
  _globals['_CHECKRESPONSE']._serialized_end=749
  _globals['_AUTHORIZATION']._serialized_start=751
  _globals['_AUTHORIZATION']._serialized_end=852
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/filters/http/ip_tagging/v3/ip_tagging.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/filters/http/ip_tagging/v3/ip_tagging.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<envoy/extensions/filters/http/ip_tagging/v3/ip_tagging.proto\x12+envoy.extensions.filters.http.ip_tagging.v3\x1a\"envoy/config/core/v3/address.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xec\x05\n\tIPTagging\x12\x62\n\x0crequest_type\x18\x01 \x01(\x0e\x32\x42.envoy.extensions.filters.http.ip_tagging.v3.IPTagging.RequestTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12W\n\x07ip_tags\x18\x04 \x03(\x0b\x32<.envoy.extensions.filters.http.ip_tagging.v3.IPTagging.IPTagB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12Y\n\rip_tag_header\x18\x05 \x01(\x0b\x32\x42.envoy.extensions.filters.http.ip_tagging.v3.IPTagging.IpTagHeader\x1a\x8d\x01\n\x05IPTag\x12\x13\n\x0bip_tag_name\x18\x01 \x01(\t\x12\x30\n\x07ip_list\x18\x02 \x03(\x0b\x32\x1f.envoy.config.core.v3.CidrRange:=\x9a\xc5\x88\x1e\x38\n6envoy.config.filter.http.ip_tagging.v2.IPTagging.IPTag\x1a\xc8\x01\n\x0bIpTagHeader\x12\x1d\n\x06header\x18\x01 \x01(\tB\r\xfa\x42\nr\x08\x10\x01\xc0\x01\x01\xc8\x01\x00\x12_\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32O.envoy.extensions.filters.http.ip_tagging.v3.IPTagging.IpTagHeader.HeaderAction\"9\n\x0cHeaderAction\x12\x0c\n\x08SANITIZE\x10\x00\x12\x1b\n\x17\x41PPEND_IF_EXISTS_OR_ADD\x10\x01\"3\n\x0bRequestType\x12\x08\n\x04\x42OTH\x10\x00\x12\x0c\n\x08INTERNAL\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02:7\x9a\xc5\x88\x1e\x32\n0envoy.config.filter.http.ip_tagging.v2.IPTaggingB\xb6\x01\n9io.envoyproxy.envoy.extensions.filters.http.ip_tagging.v3B\x0eIpTaggingProtoP\x01Z_github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/ip_tagging/v3;ip_taggingv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.ip_tagging.v3.ip_tagging_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n9io.envoyproxy.envoy.extensions.filters.http.ip_tagging.v3B\016IpTaggingProtoP\001Z_github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/ip_tagging/v3;ip_taggingv3\272\200\310\321\006\002\020\002'
  _globals['_IPTAGGING_IPTAG']._loaded_options = None
  _globals['_IPTAGGING_IPTAG']._serialized_options = b'\232\305\210\0368\n6envoy.config.filter.http.ip_tagging.v2.IPTagging.IPTag'
  _globals['_IPTAGGING_IPTAGHEADER'].fields_by_name['header']._loaded_options = None
  _globals['_IPTAGGING_IPTAGHEADER'].fields_by_name['header']._serialized_options = b'\372B\nr\010\020\001\300\001\001\310\001\000'
  _globals['_IPTAGGING'].fields_by_name['request_type']._loaded_options = None
  _globals['_IPTAGGING'].fields_by_name['request_type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_IPTAGGING'].fields_by_name['ip_tags']._loaded_options = None
  _globals['_IPTAGGING'].fields_by_name['ip_tags']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_IPTAGGING']._loaded_options = None
  _globals['_IPTAGGING']._serialized_options = b'\232\305\210\0362\n0envoy.config.filter.http.ip_tagging.v2.IPTagging'
  _globals['_IPTAGGING']._serialized_start=237
  _globals['_IPTAGGING']._serialized_end=985
  _globals['_IPTAGGING_IPTAG']._serialized_start=531
  _globals['_IPTAGGING_IPTAG']._serialized_end=672
  _globals['_IPTAGGING_IPTAGHEADER']._serialized_start=675
  _globals['_IPTAGGING_IPTAGHEADER']._serialized_end=875
  _globals['_IPTAGGING_IPTAGHEADER_HEADERACTION']._serialized_start=818
  _globals['_IPTAGGING_IPTAGHEADER_HEADERACTION']._serialized_end=875
  _globals['_IPTAGGING_REQUESTTYPE']._serialized_start=877
  _globals['_IPTAGGING_REQUESTTYPE']._serialized_end=928
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/api/backend.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'google/api/backend.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18google/api/backend.proto\x12\ngoogle.api\"1\n\x07\x42\x61\x63kend\x12&\n\x05rules\x18\x01 \x03(\x0b\x32\x17.google.api.BackendRule\"\xb2\x04\n\x0b\x42\x61\x63kendRule\x12\x10\n\x08selector\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x10\n\x08\x64\x65\x61\x64line\x18\x03 \x01(\x01\x12\x18\n\x0cmin_deadline\x18\x04 \x01(\x01\x42\x02\x18\x01\x12\x1a\n\x12operation_deadline\x18\x05 \x01(\x01\x12\x41\n\x10path_translation\x18\x06 \x01(\x0e\x32\'.google.api.BackendRule.PathTranslation\x12\x16\n\x0cjwt_audience\x18\x07 \x01(\tH\x00\x12\x16\n\x0c\x64isable_auth\x18\x08 \x01(\x08H\x00\x12\x10\n\x08protocol\x18\t \x01(\t\x12^\n\x1doverrides_by_request_protocol\x18\n \x03(\x0b\x32\x37.google.api.BackendRule.OverridesByRequestProtocolEntry\x1aZ\n\x1fOverridesByRequestProtocolEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.api.BackendRule:\x02\x38\x01\"e\n\x0fPathTranslation\x12 \n\x1cPATH_TRANSLATION_UNSPECIFIED\x10\x00\x12\x14\n\x10\x43ONSTANT_ADDRESS\x10\x01\x12\x1a\n\x16\x41PPEND_PATH_TO_ADDRESS\x10\x02\x42\x10\n\x0e\x61uthenticationBn\n\x0e\x63om.google.apiB\x0c\x42\x61\x63kendProtoP\x01ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\xa2\x02\x04GAPIb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.backend_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.google.apiB\014BackendProtoP\001ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\242\002\004GAPI'
  _globals['_BACKENDRULE_OVERRIDESBYREQUESTPROTOCOLENTRY']._loaded_options = None
  _globals['_BACKENDRULE_OVERRIDESBYREQUESTPROTOCOLENTRY']._serialized_options = b'8\001'
  _globals['_BACKENDRULE'].fields_by_name['min_deadline']._loaded_options = None
  _globals['_BACKENDRULE'].fields_by_name['min_deadline']._serialized_options = b'\030\001'
  _globals['_BACKEND']._serialized_start=40
  _globals['_BACKEND']._serialized_end=89
  _globals['_BACKENDRULE']._serialized_start=92
  _globals['_BACKENDRULE']._serialized_end=654
  _globals['_BACKENDRULE_OVERRIDESBYREQUESTPROTOCOLENTRY']._serialized_start=443
  _globals['_BACKENDRULE_OVERRIDESBYREQUESTPROTOCOLENTRY']._serialized_end=533
  _globals['_BACKENDRULE_PATHTRANSLATION']._serialized_start=535
  _globals['_BACKENDRULE_PATHTRANSLATION']._serialized_end=636
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/api/label.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'google/api/label.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16google/api/label.proto\x12\ngoogle.api\"\x9c\x01\n\x0fLabelDescriptor\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x39\n\nvalue_type\x18\x02 \x01(\x0e\x32%.google.api.LabelDescriptor.ValueType\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\",\n\tValueType\x12\n\n\x06STRING\x10\x00\x12\x08\n\x04\x42OOL\x10\x01\x12\t\n\x05INT64\x10\x02\x42_\n\x0e\x63om.google.apiB\nLabelProtoP\x01Z5google.golang.org/genproto/googleapis/api/label;label\xf8\x01\x01\xa2\x02\x04GAPIb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.label_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.google.apiB\nLabelProtoP\001Z5google.golang.org/genproto/googleapis/api/label;label\370\001\001\242\002\004GAPI'
  _globals['_LABELDESCRIPTOR']._serialized_start=39
  _globals['_LABELDESCRIPTOR']._serialized_end=195
  _globals['_LABELDESCRIPTOR_VALUETYPE']._serialized_start=151
  _globals['_LABELDESCRIPTOR_VALUETYPE']._serialized_end=195
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/wasm/v3/wasm.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/wasm/v3/wasm.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import backoff_pb2 as envoy_dot_config_dot_core_dot_v3_dot_backoff__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#envoy/extensions/wasm/v3/wasm.proto\x12\x18\x65nvoy.extensions.wasm.v3\x1a\"envoy/config/core/v3/backoff.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x19google/protobuf/any.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\"F\n\x0cReloadConfig\x12\x36\n\x07\x62\x61\x63koff\x18\x01 \x01(\x0b\x32%.envoy.config.core.v3.BackoffStrategy\"\xf5\x01\n\x1b\x43\x61pabilityRestrictionConfig\x12l\n\x14\x61llowed_capabilities\x18\x01 \x03(\x0b\x32N.envoy.extensions.wasm.v3.CapabilityRestrictionConfig.AllowedCapabilitiesEntry\x1ah\n\x18\x41llowedCapabilitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12;\n\x05value\x18\x02 \x01(\x0b\x32,.envoy.extensions.wasm.v3.SanitizationConfig:\x02\x38\x01\"\x14\n\x12SanitizationConfig\"\x97\x02\n\x08VmConfig\x12\r\n\x05vm_id\x18\x01 \x01(\t\x12\x0f\n\x07runtime\x18\x02 \x01(\t\x12\x33\n\x04\x63ode\x18\x03 \x01(\x0b\x32%.envoy.config.core.v3.AsyncDataSource\x12+\n\rconfiguration\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x19\n\x11\x61llow_precompiled\x18\x05 \x01(\x08\x12\x1f\n\x17nack_on_code_cache_miss\x18\x06 \x01(\x08\x12M\n\x15\x65nvironment_variables\x18\x07 \x01(\x0b\x32..envoy.extensions.wasm.v3.EnvironmentVariables\"\xb2\x01\n\x14\x45nvironmentVariables\x12\x15\n\rhost_env_keys\x18\x01 \x03(\t\x12Q\n\nkey_values\x18\x02 \x03(\x0b\x32=.envoy.extensions.wasm.v3.EnvironmentVariables.KeyValuesEntry\x1a\x30\n\x0eKeyValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x97\x03\n\x0cPluginConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07root_id\x18\x02 \x01(\t\x12\x37\n\tvm_config\x18\x03 \x01(\x0b\x32\".envoy.extensions.wasm.v3.VmConfigH\x00\x12+\n\rconfiguration\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x1e\n\tfail_open\x18\x05 \x01(\x08\x42\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12?\n\x0e\x66\x61ilure_policy\x18\x07 \x01(\x0e\x32\'.envoy.extensions.wasm.v3.FailurePolicy\x12=\n\rreload_config\x18\x08 \x01(\x0b\x32&.envoy.extensions.wasm.v3.ReloadConfig\x12\\\n\x1d\x63\x61pability_restriction_config\x18\x06 \x01(\x0b\x32\x35.envoy.extensions.wasm.v3.CapabilityRestrictionConfigB\x04\n\x02vm\"X\n\x0bWasmService\x12\x36\n\x06\x63onfig\x18\x01 \x01(\x0b\x32&.envoy.extensions.wasm.v3.PluginConfig\x12\x11\n\tsingleton\x18\x02 \x01(\x08*Q\n\rFailurePolicy\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0f\n\x0b\x46\x41IL_RELOAD\x10\x01\x12\x0f\n\x0b\x46\x41IL_CLOSED\x10\x02\x12\r\n\tFAIL_OPEN\x10\x03\x42\x85\x01\n&io.envoyproxy.envoy.extensions.wasm.v3B\tWasmProtoP\x01ZFgithub.com/envoyproxy/go-control-plane/envoy/extensions/wasm/v3;wasmv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.wasm.v3.wasm_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&io.envoyproxy.envoy.extensions.wasm.v3B\tWasmProtoP\001ZFgithub.com/envoyproxy/go-control-plane/envoy/extensions/wasm/v3;wasmv3\272\200\310\321\006\002\020\002'
  _globals['_CAPABILITYRESTRICTIONCONFIG_ALLOWEDCAPABILITIESENTRY']._loaded_options = None
  _globals['_CAPABILITYRESTRICTIONCONFIG_ALLOWEDCAPABILITIESENTRY']._serialized_options = b'8\001'
  _globals['_ENVIRONMENTVARIABLES_KEYVALUESENTRY']._loaded_options = None
  _globals['_ENVIRONMENTVARIABLES_KEYVALUESENTRY']._serialized_options = b'8\001'
  _globals['_PLUGINCONFIG'].fields_by_name['fail_open']._loaded_options = None
  _globals['_PLUGINCONFIG'].fields_by_name['fail_open']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _globals['_FAILUREPOLICY']._serialized_start=1534
  _globals['_FAILUREPOLICY']._serialized_end=1615
  _globals['_RELOADCONFIG']._serialized_start=229
  _globals['_RELOADCONFIG']._serialized_end=299
  _globals['_CAPABILITYRESTRICTIONCONFIG']._serialized_start=302
  _globals['_CAPABILITYRESTRICTIONCONFIG']._serialized_end=547
  _globals['_CAPABILITYRESTRICTIONCONFIG_ALLOWEDCAPABILITIESENTRY']._serialized_start=443
  _globals['_CAPABILITYRESTRICTIONCONFIG_ALLOWEDCAPABILITIESENTRY']._serialized_end=547
  _globals['_SANITIZATIONCONFIG']._serialized_start=549
  _globals['_SANITIZATIONCONFIG']._serialized_end=569
  _globals['_VMCONFIG']._serialized_start=572
  _globals['_VMCONFIG']._serialized_end=851
  _globals['_ENVIRONMENTVARIABLES']._serialized_start=854
  _globals['_ENVIRONMENTVARIABLES']._serialized_end=1032
  _globals['_ENVIRONMENTVARIABLES_KEYVALUESENTRY']._serialized_start=984
  _globals['_ENVIRONMENTVARIABLES_KEYVALUESENTRY']._serialized_end=1032
  _globals['_PLUGINCONFIG']._serialized_start=1035
  _globals['_PLUGINCONFIG']._serialized_end=1442
  _globals['_WASMSERVICE']._serialized_start=1444
  _globals['_WASMSERVICE']._serialized_end=1532
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/resource_monitors/fixed_heap/v3/fixed_heap.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/resource_monitors/fixed_heap/v3/fixed_heap.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAenvoy/extensions/resource_monitors/fixed_heap/v3/fixed_heap.proto\x12\x30\x65nvoy.extensions.resource_monitors.fixed_heap.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x80\x01\n\x0f\x46ixedHeapConfig\x12$\n\x13max_heap_size_bytes\x18\x01 \x01(\x04\x42\x07\xfa\x42\x04\x32\x02 \x00:G\x9a\xc5\x88\x1e\x42\n@envoy.config.resource_monitor.fixed_heap.v2alpha.FixedHeapConfigB\xc0\x01\n>io.envoyproxy.envoy.extensions.resource_monitors.fixed_heap.v3B\x0e\x46ixedHeapProtoP\x01Zdgithub.com/envoyproxy/go-control-plane/envoy/extensions/resource_monitors/fixed_heap/v3;fixed_heapv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.resource_monitors.fixed_heap.v3.fixed_heap_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n>io.envoyproxy.envoy.extensions.resource_monitors.fixed_heap.v3B\016FixedHeapProtoP\001Zdgithub.com/envoyproxy/go-control-plane/envoy/extensions/resource_monitors/fixed_heap/v3;fixed_heapv3\272\200\310\321\006\002\020\002'
  _globals['_FIXEDHEAPCONFIG'].fields_by_name['max_heap_size_bytes']._loaded_options = None
  _globals['_FIXEDHEAPCONFIG'].fields_by_name['max_heap_size_bytes']._serialized_options = b'\372B\0042\002 \000'
  _globals['_FIXEDHEAPCONFIG']._loaded_options = None
  _globals['_FIXEDHEAPCONFIG']._serialized_options = b'\232\305\210\036B\n@envoy.config.resource_monitor.fixed_heap.v2alpha.FixedHeapConfig'
  _globals['_FIXEDHEAPCONFIG']._serialized_start=211
  _globals['_FIXEDHEAPCONFIG']._serialized_end=339
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from envoy.api.v2 import discovery_pb2 as envoy_dot_api_dot_v2_dot_discovery__pb2

GRPC_GENERATED_VERSION = '1.74.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in envoy/service/discovery/v2/ads_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class AggregatedDiscoveryServiceStub(object):
    """[#protodoc-title: Aggregated Discovery Service (ADS)]

    Discovery services for endpoints, clusters, routes,
    and listeners are retained in the package `envoy.api.v2` for backwards
    compatibility with existing management servers. New development in discovery
    services should proceed in the package `envoy.service.discovery.v2`.

    See https://github.com/envoyproxy/envoy-api#apis for a description of the role of
    ADS and how it is intended to be used by a management server. ADS requests
    have the same structure as their singleton xDS counterparts, but can
    multiplex many resource types on a single stream. The type_url in the
    DiscoveryRequest/DiscoveryResponse provides sufficient information to recover
    the multiplexed singleton APIs at the Envoy instance and management server.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StreamAggregatedResources = channel.stream_stream(
                '/envoy.service.discovery.v2.AggregatedDiscoveryService/StreamAggregatedResources',
                request_serializer=envoy_dot_api_dot_v2_dot_discovery__pb2.DiscoveryRequest.SerializeToString,
                response_deserializer=envoy_dot_api_dot_v2_dot_discovery__pb2.DiscoveryResponse.FromString,
                _registered_method=True)
        self.DeltaAggregatedResources = channel.stream_stream(
                '/envoy.service.discovery.v2.AggregatedDiscoveryService/DeltaAggregatedResources',
                request_serializer=envoy_dot_api_dot_v2_dot_discovery__pb2.DeltaDiscoveryRequest.SerializeToString,
                response_deserializer=envoy_dot_api_dot_v2_dot_discovery__pb2.DeltaDiscoveryResponse.FromString,
                _registered_method=True)


class AggregatedDiscoveryServiceServicer(object):
    """[#protodoc-title: Aggregated Discovery Service (ADS)]

    Discovery services for endpoints, clusters, routes,
    and listeners are retained in the package `envoy.api.v2` for backwards
    compatibility with existing management servers. New development in discovery
    services should proceed in the package `envoy.service.discovery.v2`.

    See https://github.com/envoyproxy/envoy-api#apis for a description of the role of
    ADS and how it is intended to be used by a management server. ADS requests
    have the same structure as their singleton xDS counterparts, but can
    multiplex many resource types on a single stream. The type_url in the
    DiscoveryRequest/DiscoveryResponse provides sufficient information to recover
    the multiplexed singleton APIs at the Envoy instance and management server.
    """

    def StreamAggregatedResources(self, request_iterator, context):
        """This is a gRPC-only API.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeltaAggregatedResources(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AggregatedDiscoveryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StreamAggregatedResources': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamAggregatedResources,
                    request_deserializer=envoy_dot_api_dot_v2_dot_discovery__pb2.DiscoveryRequest.FromString,
                    response_serializer=envoy_dot_api_dot_v2_dot_discovery__pb2.DiscoveryResponse.SerializeToString,
            ),
            'DeltaAggregatedResources': grpc.stream_stream_rpc_method_handler(
                    servicer.DeltaAggregatedResources,
                    request_deserializer=envoy_dot_api_dot_v2_dot_discovery__pb2.DeltaDiscoveryRequest.FromString,
                    response_serializer=envoy_dot_api_dot_v2_dot_discovery__pb2.DeltaDiscoveryResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'envoy.service.discovery.v2.AggregatedDiscoveryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('envoy.service.discovery.v2.AggregatedDiscoveryService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class AggregatedDiscoveryService(object):
    """[#protodoc-title: Aggregated Discovery Service (ADS)]

    Discovery services for endpoints, clusters, routes,
    and listeners are retained in the package `envoy.api.v2` for backwards
    compatibility with existing management servers. New development in discovery
    services should proceed in the package `envoy.service.discovery.v2`.

    See https://github.com/envoyproxy/envoy-api#apis for a description of the role of
    ADS and how it is intended to be used by a management server. ADS requests
    have the same structure as their singleton xDS counterparts, but can
    multiplex many resource types on a single stream. The type_url in the
    DiscoveryRequest/DiscoveryResponse provides sufficient information to recover
    the multiplexed singleton APIs at the Envoy instance and management server.
    """

    @staticmethod
    def StreamAggregatedResources(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/envoy.service.discovery.v2.AggregatedDiscoveryService/StreamAggregatedResources',
            envoy_dot_api_dot_v2_dot_discovery__pb2.DiscoveryRequest.SerializeToString,
            envoy_dot_api_dot_v2_dot_discovery__pb2.DiscoveryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeltaAggregatedResources(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/envoy.service.discovery.v2.AggregatedDiscoveryService/DeltaAggregatedResources',
            envoy_dot_api_dot_v2_dot_discovery__pb2.DeltaDiscoveryRequest.SerializeToString,
            envoy_dot_api_dot_v2_dot_discovery__pb2.DeltaDiscoveryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/filter/network/ext_authz/v2/ext_authz.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/filter/network/ext_authz/v2/ext_authz.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import grpc_service_pb2 as envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8envoy/config/filter/network/ext_authz/v2/ext_authz.proto\x12(envoy.config.filter.network.ext_authz.v2\x1a$envoy/api/v2/core/grpc_service.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x9c\x01\n\x08\x45xtAuthz\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x34\n\x0cgrpc_service\x18\x02 \x01(\x0b\x32\x1e.envoy.api.v2.core.GrpcService\x12\x1a\n\x12\x66\x61ilure_mode_allow\x18\x03 \x01(\x08\x12 \n\x18include_peer_certificate\x18\x04 \x01(\x08\x42\xe3\x01\n6io.envoyproxy.envoy.config.filter.network.ext_authz.v2B\rExtAuthzProtoP\x01Z[github.com/envoyproxy/go-control-plane/envoy/config/filter/network/ext_authz/v2;ext_authzv2\xf2\x98\xfe\x8f\x05/\x12-envoy.extensions.filters.network.ext_authz.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.network.ext_authz.v2.ext_authz_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n6io.envoyproxy.envoy.config.filter.network.ext_authz.v2B\rExtAuthzProtoP\001Z[github.com/envoyproxy/go-control-plane/envoy/config/filter/network/ext_authz/v2;ext_authzv2\362\230\376\217\005/\022-envoy.extensions.filters.network.ext_authz.v3\272\200\310\321\006\002\020\001'
  _globals['_EXTAUTHZ'].fields_by_name['stat_prefix']._loaded_options = None
  _globals['_EXTAUTHZ'].fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002 \001'
  _globals['_EXTAUTHZ']._serialized_start=229
  _globals['_EXTAUTHZ']._serialized_end=385
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xds/annotations/v3/status.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'xds/annotations/v3/status.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fxds/annotations/v3/status.proto\x12\x12xds.annotations.v3\x1a google/protobuf/descriptor.proto\"0\n\x14\x46ileStatusAnnotation\x12\x18\n\x10work_in_progress\x18\x01 \x01(\x08\"3\n\x17MessageStatusAnnotation\x12\x18\n\x10work_in_progress\x18\x01 \x01(\x08\"1\n\x15\x46ieldStatusAnnotation\x12\x18\n\x10work_in_progress\x18\x01 \x01(\x08\"v\n\x10StatusAnnotation\x12\x18\n\x10work_in_progress\x18\x01 \x01(\x08\x12H\n\x16package_version_status\x18\x02 \x01(\x0e\x32(.xds.annotations.v3.PackageVersionStatus*]\n\x14PackageVersionStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x46ROZEN\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12 \n\x1cNEXT_MAJOR_VERSION_CANDIDATE\x10\x03:^\n\x0b\x66ile_status\x12\x1c.google.protobuf.FileOptions\x18\xea\xc8\x94l \x01(\x0b\x32(.xds.annotations.v3.FileStatusAnnotation:g\n\x0emessage_status\x12\x1f.google.protobuf.MessageOptions\x18\xea\xc8\x94l \x01(\x0b\x32+.xds.annotations.v3.MessageStatusAnnotation:a\n\x0c\x66ield_status\x12\x1d.google.protobuf.FieldOptions\x18\xea\xc8\x94l \x01(\x0b\x32).xds.annotations.v3.FieldStatusAnnotationB+Z)github.com/cncf/xds/go/xds/annotations/v3b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xds.annotations.v3.status_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/cncf/xds/go/xds/annotations/v3'
  _globals['_PACKAGEVERSIONSTATUS']._serialized_start=363
  _globals['_PACKAGEVERSIONSTATUS']._serialized_end=456
  _globals['_FILESTATUSANNOTATION']._serialized_start=89
  _globals['_FILESTATUSANNOTATION']._serialized_end=137
  _globals['_MESSAGESTATUSANNOTATION']._serialized_start=139
  _globals['_MESSAGESTATUSANNOTATION']._serialized_end=190
  _globals['_FIELDSTATUSANNOTATION']._serialized_start=192
  _globals['_FIELDSTATUSANNOTATION']._serialized_end=241
  _globals['_STATUSANNOTATION']._serialized_start=243
  _globals['_STATUSANNOTATION']._serialized_end=361
# @@protoc_insertion_point(module_scope)
